@@ -10,11 +10,11 @@ class MyObject:  # noqa: D101
 
 
 @pytest.mark.parametrize(
-    ('obj', 'expected_result'),
+    ("obj", "expected_result"),
     [
-        (obj, 'object'),
-        (MyObject, 'tests.core.test_utils.MyObject'),
-        (MyObject(), 'tests.core.test_utils.MyObject'),
+        (obj, "object"),
+        (MyObject, "tests.core.test_utils.MyObject"),
+        (MyObject(), "tests.core.test_utils.MyObject"),
     ],
 )
 def test_get_object_class_absolute_name(obj: object, expected_result: str) -> None:
@@ -22,12 +22,12 @@ def test_get_object_class_absolute_name(obj: object, expected_result: str) -> No
 
 
 @pytest.mark.parametrize(
-    ('obj', 'expected_result'),
+    ("obj", "expected_result"),
     [
-        ('                 abc                ', 'abc'),
-        ('                 abc\nabc                ', 'abc abc'),
-        ('                 abc  abc                ', 'abc abc'),
-        ('                 abc   abc                ', 'abc abc'),
+        ("                 abc                ", "abc"),
+        ("                 abc\nabc                ", "abc abc"),
+        ("                 abc  abc                ", "abc abc"),
+        ("                 abc   abc                ", "abc abc"),
     ],
 )
 def test_trim_and_plain_text(obj: str, expected_result: str) -> None:
